@@ -32,6 +32,8 @@
 #include <X11/Xlib-xcb.h>
 #endif
 
+#include <algorithm>
+
 namespace Breeze
 {
 
@@ -46,7 +48,7 @@ namespace Breeze
     //____________________________________________________________________
     #if BREEZE_USE_KDE4
     Helper::Helper( const QByteArray& name ):
-        _componentData( name, 0, KComponentData::SkipMainComponentRegistration ),
+        _componentData( name, nullptr, KComponentData::SkipMainComponentRegistration ),
         _config( _componentData.config() )
     { init(); }
     #endif
@@ -473,8 +475,7 @@ namespace Breeze
         }
 
         painter->restore();
-        return;
-    }
+   }
 
     //______________________________________________________________________________
     void Helper::renderFocusLine( QPainter* painter, const QRect& rect, const QColor& color ) const
@@ -760,8 +761,6 @@ namespace Breeze
         painter->translate( baseRect.topLeft() );
         painter->drawPath( path );
 
-        return;
-
     }
 
     //______________________________________________________________________________
@@ -833,8 +832,7 @@ namespace Breeze
 
         }
 
-        return;
-
+        
     }
 
     //______________________________________________________________________________
@@ -1052,8 +1050,7 @@ namespace Breeze
             painter->drawRoundedRect( baseRect, radius, radius );
         }
 
-        return;
-
+        
     }
 
     //______________________________________________________________________________
@@ -1078,8 +1075,7 @@ namespace Breeze
             painter->drawEllipse( grooveRect );
         }
 
-        return;
-
+        
     }
 
     //______________________________________________________________________________
@@ -1118,8 +1114,7 @@ namespace Breeze
 
         }
 
-        return;
-
+        
     }
 
     //______________________________________________________________________________
@@ -1186,8 +1181,7 @@ namespace Breeze
             painter->drawRoundedRect( baseRect, radius, radius );
         }
 
-        return;
-
+        
     }
 
 
@@ -1244,8 +1238,6 @@ namespace Breeze
         painter->setBrush( pixmap );
         painter->drawRoundedRect( baseRect, radius, radius );
 
-        return;
-
     }
 
     //______________________________________________________________________________
@@ -1258,7 +1250,7 @@ namespace Breeze
         painter->setRenderHint( QPainter::Antialiasing, true );
 
         const QRectF baseRect( rect );
-        const qreal radius( 0.5*Metrics::ScrollBar_SliderWidth );
+        const qreal radius( 0.5 * std::min({baseRect.width(), baseRect.height(), (qreal)Metrics::ScrollBar_SliderWidth}) );
 
         // content
         if( color.isValid() )
@@ -1268,8 +1260,7 @@ namespace Breeze
             painter->drawRoundedRect( baseRect, radius, radius );
         }
 
-        return;
-
+        
     }
 
     //______________________________________________________________________________
@@ -1325,9 +1316,7 @@ namespace Breeze
         painter->setPen( QPen( color, 1.1 ) );
         painter->drawPolyline( arrow );
         painter->restore();
-
-        return;
-    }
+   }
 
     //______________________________________________________________________________
     void Helper::renderDecorationButton( QPainter* painter, const QRect& rect, const QColor& color, ButtonType buttonType, bool inverted ) const
@@ -1411,7 +1400,6 @@ namespace Breeze
         }
 
         painter->restore();
-        return;
 
     }
 
